[ekiga] s/dnd/busy: The right status in all software I know is busy, not dnd.



commit 275f15833c83c554889dccf2051c3d5a077694bb
Author: Damien Sandras <dsandras beip be>
Date:   Tue May 1 17:08:42 2012 +0200

    s/dnd/busy: The right status in all software I know is busy, not dnd.

 ekiga.schemas.in.in                         |    4 +-
 lib/engine/components/opal/opal-account.cpp |    6 ++--
 lib/engine/gui/gtk-core/gtk-core.cpp        |    2 +-
 lib/engine/gui/gtk-frontend/statusicon.cpp  |    2 +-
 src/gui/statusmenu.cpp                      |   32 +++++++++++++-------------
 5 files changed, 23 insertions(+), 23 deletions(-)
---
diff --git a/ekiga.schemas.in.in b/ekiga.schemas.in.in
index e693985..eb71bc6 100644
--- a/ekiga.schemas.in.in
+++ b/ekiga.schemas.in.in
@@ -133,8 +133,8 @@
       </locale>
     </schema>
     <schema>
-      <key>/schemas/apps/@PACKAGE_NAME@/general/personal_data/dnd_custom_status</key>
-      <applyto>/apps/@PACKAGE_NAME@/general/personal_data/dnd_custom_status</applyto>
+      <key>/schemas/apps/@PACKAGE_NAME@/general/personal_data/busy_custom_status</key>
+      <applyto>/apps/@PACKAGE_NAME@/general/personal_data/busy_custom_status</applyto>
       <type>list</type>
       <list_type>string</list_type>
       <default>[]</default>
diff --git a/lib/engine/components/opal/opal-account.cpp b/lib/engine/components/opal/opal-account.cpp
index 3cb07dd..f235409 100644
--- a/lib/engine/components/opal/opal-account.cpp
+++ b/lib/engine/components/opal/opal-account.cpp
@@ -546,7 +546,7 @@ Opal::Account::publish (const Ekiga::PersonalDetails& details)
     personal_state = OpalPresenceInfo::Available;
   else if (presence == "away")
     personal_state = OpalPresenceInfo::Away;
-  else if (presence == "dnd")
+  else if (presence == "busy")
     personal_state = OpalPresenceInfo::Busy;
   else {  // ekiga knows only these three presence types
     std::string s = "Warning: Unknown presence type ";
@@ -761,7 +761,7 @@ Opal::Account::OnPresenceChange (OpalPresentity& /*presentity*/,
           || note.Find ("meeting") != P_MAX_INDEX
           || note.Find ("do not disturb") != P_MAX_INDEX
           || note.Find ("busy") != P_MAX_INDEX) {
-        new_presence = "dnd";
+        new_presence = "busy";
       }
       else if (note.Find ("away") != P_MAX_INDEX
                || note.Find ("out") != P_MAX_INDEX
@@ -788,7 +788,7 @@ Opal::Account::OnPresenceChange (OpalPresentity& /*presentity*/,
     new_presence = "away";
     break;
   case OpalPresenceInfo::Busy:
-    new_presence = "dnd";
+    new_presence = "busy";
     break;
   case OpalPresenceInfo::Appointment:
     new_presence = "busy";
diff --git a/lib/engine/gui/gtk-core/gtk-core.cpp b/lib/engine/gui/gtk-core/gtk-core.cpp
index 5ac3049..c5be5d1 100644
--- a/lib/engine/gui/gtk-core/gtk-core.cpp
+++ b/lib/engine/gui/gtk-core/gtk-core.cpp
@@ -64,7 +64,7 @@ Gtk::Core::Core ()
   gtk_icon_set_unref (icon_set);
 
   icon_set = gtk_icon_factory_lookup_default (GM_STOCK_STATUS_DND);
-  gtk_icon_factory_add (factory, "dnd", icon_set);
+  gtk_icon_factory_add (factory, "busy", icon_set);
   gtk_icon_set_unref (icon_set);
 
   icon_set = gtk_icon_factory_lookup_default (GM_STOCK_STATUS_INACALL);
diff --git a/lib/engine/gui/gtk-frontend/statusicon.cpp b/lib/engine/gui/gtk-frontend/statusicon.cpp
index 92999df..0b31e05 100644
--- a/lib/engine/gui/gtk-frontend/statusicon.cpp
+++ b/lib/engine/gui/gtk-frontend/statusicon.cpp
@@ -452,7 +452,7 @@ statusicon_set_status (StatusIcon *statusicon,
   /* Update the status icon */
   if (presence == "away")
     gtk_status_icon_set_from_icon_name (GTK_STATUS_ICON (statusicon), "user-away");
-  else if (presence == "dnd")
+  else if (presence == "busy")
     gtk_status_icon_set_from_icon_name (GTK_STATUS_ICON (statusicon), "user-busy");
   else if (presence == "offline")
     gtk_status_icon_set_from_icon_name (GTK_STATUS_ICON (statusicon), "user-offline");
diff --git a/src/gui/statusmenu.cpp b/src/gui/statusmenu.cpp
index daf8ae4..9012623 100644
--- a/src/gui/statusmenu.cpp
+++ b/src/gui/statusmenu.cpp
@@ -70,15 +70,15 @@ enum MessageType
 {
   TYPE_ONLINE,             // Generic online message
   TYPE_AWAY,               // Generic away message
-  TYPE_DND,                // Generic Do Not Disturb message
+  TYPE_BUSY,                // Generic Do Not Disturb message
   NUM_STATUS_TYPES,
   TYPE_CUSTOM_ONLINE,      // Custom online message
   TYPE_CUSTOM_AWAY,        // Custom away message
-  TYPE_CUSTOM_DND,         // Custom DND message
+  TYPE_CUSTOM_BUSY,         // Custom BUSY message
   NUM_STATUS_CUSTOM_TYPES,
   TYPE_CUSTOM_ONLINE_NEW,  // Add new custom online message
   TYPE_CUSTOM_AWAY_NEW,    // Add new custom away message
-  TYPE_CUSTOM_DND_NEW,     // Add new custom dnd message
+  TYPE_CUSTOM_BUSY_NEW,     // Add new custom busy message
   TYPE_CLEAR               // Clear custom message(s)
 };
 
@@ -93,14 +93,14 @@ const char* status_types_names[] =
 {
   "online",
   "away",
-  "dnd"
+  "busy"
 };
 
 const char* status_types_keys[] =
 {
   PERSONAL_DATA_KEY "online_custom_status",
   PERSONAL_DATA_KEY "away_custom_status",
-  PERSONAL_DATA_KEY "dnd_custom_status"
+  PERSONAL_DATA_KEY "busy_custom_status"
 };
 
 
@@ -210,7 +210,7 @@ status_menu_clear_status_message_dialog_run (StatusMenu *self);
  *
  * @param self is the StatusMenu
  * @param option is the defined message type (TYPE_CUSTOM_ONLINE,
- * TYPE_CUSTOM_AWAY, TYPE_CUSTOM_DND)
+ * TYPE_CUSTOM_AWAY, TYPE_CUSTOM_BUSY)
  */
 static void
 status_menu_new_status_message_dialog_run (StatusMenu *self,
@@ -276,8 +276,8 @@ status_menu_option_changed (GtkComboBox *box,
         self->priv->personal_details->set_presence_info ("away", "");
         break;
 
-      case TYPE_DND:
-        self->priv->personal_details->set_presence_info ("dnd", "");
+      case TYPE_BUSY:
+        self->priv->personal_details->set_presence_info ("busy", "");
         break;
 
       case TYPE_CUSTOM_ONLINE:
@@ -288,8 +288,8 @@ status_menu_option_changed (GtkComboBox *box,
         self->priv->personal_details->set_presence_info ("away", status);
         break;
 
-      case TYPE_CUSTOM_DND:
-        self->priv->personal_details->set_presence_info ("dnd", status);
+      case TYPE_CUSTOM_BUSY:
+        self->priv->personal_details->set_presence_info ("busy", status);
         break;
 
       case TYPE_CUSTOM_ONLINE_NEW:
@@ -300,8 +300,8 @@ status_menu_option_changed (GtkComboBox *box,
         status_menu_new_status_message_dialog_run (self, TYPE_CUSTOM_AWAY);
         break;
 
-      case TYPE_CUSTOM_DND_NEW:
-        status_menu_new_status_message_dialog_run (self, TYPE_CUSTOM_DND);
+      case TYPE_CUSTOM_BUSY_NEW:
+        status_menu_new_status_message_dialog_run (self, TYPE_CUSTOM_BUSY);
         break;
 
       case TYPE_CLEAR:
@@ -462,13 +462,13 @@ status_menu_set_option (StatusMenu *self,
                         COL_MESSAGE, &sstatus, -1);
 
     // Check if it is a custom status message and if it is in the list
-    if (i == TYPE_CUSTOM_ONLINE || i == TYPE_CUSTOM_AWAY || i == TYPE_CUSTOM_DND) {
+    if (i == TYPE_CUSTOM_ONLINE || i == TYPE_CUSTOM_AWAY || i == TYPE_CUSTOM_BUSY) {
       if (presence == status_types_names[i - NUM_STATUS_TYPES - 1] && status == sstatus)
         break;
     }
 
     // Long status empty, the user did not set a custom message
-    if (i == TYPE_ONLINE || i == TYPE_AWAY || i == TYPE_DND) {
+    if (i == TYPE_ONLINE || i == TYPE_AWAY || i == TYPE_BUSY) {
       if (status.empty () && presence == status_types_names[i])
         break;
     }
@@ -570,7 +570,7 @@ status_menu_clear_status_message_dialog_run (StatusMenu *self)
       gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter,
                           COL_MESSAGE_TYPE, &i, -1);
 
-      if (i == TYPE_CUSTOM_ONLINE || i == TYPE_CUSTOM_AWAY || i == TYPE_CUSTOM_DND) {
+      if (i == TYPE_CUSTOM_ONLINE || i == TYPE_CUSTOM_AWAY || i == TYPE_CUSTOM_BUSY) {
 
         gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter,
                             COL_ICON, &pixbuf,
@@ -851,7 +851,7 @@ status_menu_new (Ekiga::ServiceCore & core)
                         status_menu_custom_messages_changed, self);
   gm_conf_notifier_add (PERSONAL_DATA_KEY "away_custom_status",
                         status_menu_custom_messages_changed, self);
-  gm_conf_notifier_add (PERSONAL_DATA_KEY "dnd_custom_status",
+  gm_conf_notifier_add (PERSONAL_DATA_KEY "busy_custom_status",
                         status_menu_custom_messages_changed, self);
 
   conn = self->priv->personal_details->updated.connect (boost::bind (&on_details_updated, self));



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]